__version__ = "0.1.36"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = u'(HEAD detached at v0.1.36)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'c51a1b25a27186a96e35eda31df620352a92c2f5'
__git_head_subject__ = u'Finished Release v0.1.36'
__git_head_message__ = u''
__git_dirty_diff__ = u''